package com.yingji.quartz;

import cn.hutool.core.util.StrUtil;
import com.yingji.entity.dto.request.AlarmRequest;
import com.yingji.redis.RedisCache;
import com.yingji.service.AlarmService;
import com.yingji.service.SourceService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * 110数据保存定时任务
 *
 * @author wu
 * @since 2024/05/06 10:18
 */
@Configuration
@EnableScheduling
public class AlarmQuartz {

    public static final Logger log = LoggerFactory.getLogger(AlarmQuartz.class);

    @Resource
    private AlarmService alarmService;

    @Resource
    private SourceService sourceService;

    @Resource
    private RedisCache redisCache;

    /**
     * 保存所有id
     */
    @Scheduled(cron = "0 */5 * * * ? ")
    private void savaData() {
        // 获取token
        String token = alarmService.getToken();
        if (StrUtil.isEmpty(token)) {
            return;
        }
        String yesterdayStr;
        String effectiveTimeStr = redisCache.getCacheObject("effectiveTimeStr");
        log.info("redis的缓存时间是==========================" + effectiveTimeStr );
        if (StrUtil.isNotEmpty(effectiveTimeStr)) {
            yesterdayStr = effectiveTimeStr;
        } else {
            // 获取五分钟前的时间
            LocalDateTime yesterday = LocalDateTime.now().minusMinutes(5);
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmm");
            yesterdayStr = yesterday.format(formatter) + "00";
        }
        // 定义起始页
        int pageIndex = 1;
        // 定义每页显示条数
        int pageSize = 5000;
        // 定义总数据条数
        int size = 0;
        // 定义type
        String type = "getId";
        // 查询id条件
        AlarmRequest req = new AlarmRequest();
        req.setType(type);
        req.setValue(yesterdayStr);
        req.setPageIndex(pageIndex);
        req.setPageSize(pageSize);
        while (true) {
            List<String> data = alarmService.findDataIdList(req, token);
            if (data == null) {
                redisCache.setCacheObject("effectiveTimeStr", yesterdayStr);
                return;
            }
            sourceService.addList(data);
            size += data.size();
            if (data.size() == pageSize) {
                req.setPageIndex(pageIndex++);
                log.info("第" + pageIndex + "页==========================" + size + "条数据");
            } else {
                redisCache.deleteObject("effectiveTimeStr");
                break;
            }
        }
    }
}
